FloatingBottomNavigationStyle class

Annotations

Constructors

FloatingBottomNavigationStyle({EdgeInsets outerPadding = EdgeInsets.zero, double barHeight = 126, double compactBarHeight = 118, double barTop = 22, double compactBarTop = 20, double centerGap = 112, double compactCenterGap = 98, double centerTop = 25, bool adaptBottomSafeArea = true, Color backgroundColor = Colors.white, double blurSigma = 18, BoxShadow? backgroundShadow, FloatingBottomNavigationCurve curve = const FloatingBottomNavigationCurve(), Color selectedItemColor = const Color(0xFF1E88FF), Color unselectedItemColor = const Color(0xFF314A81), Color selectedCenterLabelColor = const Color(0xFF1E88FF), Color unselectedCenterLabelColor = const Color(0xFF223D72), double itemTopPadding = 43, double itemSpacing = 5, TextStyle itemLabelStyle = const TextStyle(fontSize: 13, fontWeight: FontWeight.w500), TextStyle selectedItemLabelStyle = const TextStyle(fontSize: 13, fontWeight: FontWeight.w700), double itemIconSize = 24, double filledSelectionSize = 34, Gradient defaultSelectionGradient = const LinearGradient(colors: <Color>[Color(0xFF2E96FF), Color(0xFF37C7FF)], begin: Alignment.topCenter, end: Alignment.bottomCenter), double centerSelectedSize = 70, double centerUnselectedSize = 66, EdgeInsets centerButtonPadding = EdgeInsets.zero, Color centerButtonColor = Colors.transparent, Color centerShadowColor = const Color(0x3D8BA7D3), double centerShadowBlur = 18, Offset centerShadowOffset = const Offset(0, 8), double centerLabelSpacing = 5, TextStyle centerLabelStyle = const TextStyle(fontSize: 13, fontWeight: FontWeight.w500, height: 1), TextStyle selectedCenterLabelStyle = const TextStyle(fontSize: 13, fontWeight: FontWeight.w700, height: 1), Gradient centerForegroundGradient = const LinearGradient(begin: Alignment.topCenter, end: Alignment.bottomCenter, colors: <Color>[Colors.transparent, Color(0x240C2B63)])})
const

Properties

adaptBottomSafeArea bool
final
backgroundColor Color
final
backgroundShadow BoxShadow?
final
barHeight double
final
barTop double
final
blurSigma double
final
centerButtonColor Color
final
centerButtonPadding EdgeInsets
final
centerForegroundGradient Gradient
final
centerGap double
final
centerLabelSpacing double
final
centerLabelStyle TextStyle
final
centerSelectedSize double
final
centerShadowBlur double
final
centerShadowColor Color
final
centerShadowOffset Offset
final
centerTop double
final
centerUnselectedSize double
final
compactBarHeight double
final
compactBarTop double
final
compactCenterGap double
final
curve FloatingBottomNavigationCurve
final
defaultSelectionGradient Gradient
final
filledSelectionSize double
final
hashCode int
The hash code for this object.
no setterinherited
itemIconSize double
final
itemLabelStyle TextStyle
final
itemSpacing double
final
itemTopPadding double
final
outerPadding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCenterLabelColor Color
final
selectedCenterLabelStyle TextStyle
final
selectedItemColor Color
final
selectedItemLabelStyle TextStyle
final
unselectedCenterLabelColor Color
final
unselectedItemColor Color
final

Methods

copyWith({EdgeInsets? outerPadding, double? barHeight, double? compactBarHeight, double? barTop, double? compactBarTop, double? centerGap, double? compactCenterGap, double? centerTop, bool? adaptBottomSafeArea, Color? backgroundColor, double? blurSigma, BoxShadow? backgroundShadow, FloatingBottomNavigationCurve? curve, Color? selectedItemColor, Color? unselectedItemColor, Color? selectedCenterLabelColor, Color? unselectedCenterLabelColor, double? itemTopPadding, double? itemSpacing, TextStyle? itemLabelStyle, TextStyle? selectedItemLabelStyle, double? itemIconSize, double? filledSelectionSize, Gradient? defaultSelectionGradient, double? centerSelectedSize, double? centerUnselectedSize, EdgeInsets? centerButtonPadding, Color? centerButtonColor, Color? centerShadowColor, double? centerShadowBlur, Offset? centerShadowOffset, double? centerLabelSpacing, TextStyle? centerLabelStyle, TextStyle? selectedCenterLabelStyle, Gradient? centerForegroundGradient}) FloatingBottomNavigationStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited